@@ -6,9 +6,12 @@ is_clipr_available <- clipr_available()
 test_that("clipr_available fails when DISPLAY is not configured; succeeds when it is", {
   # Only run this test on Travis
   skip_if_not(identical(Sys.getenv("TRAVIS"), "true"))
-  if (identical(Sys.getenv("DISPLAY"), ""))
+  if (identical(Sys.getenv("TRAVIS_CLIP"), "none"))
     expect_false(is_clipr_available)
-  if (identical(Sys.getenv("DISPLAY"), ":99.0")) {
+  if (identical(Sys.getenv("TRAVIS_CLIP"), "xclip")) {
+    expect_true(is_clipr_available)
+  }
+  if (identical(Sys.getenv("TRAVIS_CLIP"), "xsel")) {
     expect_true(is_clipr_available)
   }
 })
